@@ -187,8 +187,8 @@ protected:
     }
 };
 
-ItemPalette::ItemPalette(WorldModel* worldModel, QWidget* parent, Qt::WindowFlags flags)
-    : QDockWidget(i18n("Palette"), parent, flags), _worldModel(worldModel), _widget(0)
+ItemPalette::ItemPalette(WorldModel* worldModel, QWidget* parent)
+    : QDockWidget(i18n("Palette"), parent), _worldModel(worldModel), _widget(0)
 {
     setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
     //setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
@@ -277,7 +277,7 @@ void ItemPalette::createObjectAction(const StepCore::MetaObject* metaObject)
 void ItemPalette::showButtonTextToggled(bool b)
 {
     Settings::setShowButtonText(b);
-    Settings::self()->writeConfig();
+    Settings::self()->save();
     foreach(QToolButton* button, _toolButtons) {
         button->setToolButtonStyle(b ? Qt::ToolButtonTextBesideIcon :
                                        Qt::ToolButtonIconOnly);
