@@ -35,32 +35,33 @@
 #include <stepcore/collisionsolver.h>
 
 #include <KActionCollection>
-#include <KStandardAction>
-#include <KRecentFilesAction>
-#include <KMessageBox>
-#include <KFileDialog>
-#include <KConfigDialog>
-#include <KStandardDirs>
-#include <KStatusBar>
-#include <KLocalizedString>
 #include <KConfig>
+#include <KConfigDialog>
+#include <KIO/CopyJob>
+#include <KIO/Job>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KRecentFilesAction>
+#include <KStandardAction>
 #include <KToolBarPopupAction>
-
-#include <KIO/NetAccess>
-#include <knewstuff3/downloaddialog.h>
+#include <KNS3/DownloadDialog>
 
 #include <QAction>
-#include <QTemporaryFile>
+#include <QDir>
+#include <QFile>
+#include <QFileDialog>
+#include <QGraphicsView>
 #include <QIcon>
 #include <QItemSelectionModel>
-#include <QFile>
-#include <QGraphicsView>
-#include <QMenu>
 #include <QKeySequence>
+#include <QMenu>
+#include <QStandardPaths>
+#include <QStatusBar>
+#include <QTemporaryFile>
 
 #include <cstdlib>
 #include <ctime>
-#include <QStandardPaths>
 
 MainWindow::MainWindow()
 {
@@ -105,15 +106,15 @@ MainWindow::MainWindow()
     setCentralWidget(worldGraphicsView);
 
     connect(worldModel, SIGNAL(simulationStopped(int)), this, SLOT(simulationStopped(int)));
-    connect(worldModel->selectionModel(), SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection&)),
+    connect(worldModel->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
                                  this, SLOT(worldSelectionChanged()));
-    connect(itemPalette, SIGNAL(beginAddItem(const QString&)),
-	    worldScene,  SLOT(beginAddItem(const QString&)));
-    connect(worldScene,  SIGNAL(endAddItem(const QString&, bool)),
-	    itemPalette, SLOT(endAddItem(const QString&, bool)));
-    connect(worldScene,  SIGNAL(linkActivated(const QUrl&)),
-	    infoBrowser, SLOT(openUrl(const QUrl&)));
-    connect(worldScene,  SIGNAL(endAddItem(QString, bool)),
+    connect(itemPalette, SIGNAL(beginAddItem(QString)),
+	    worldScene,  SLOT(beginAddItem(QString)));
+    connect(worldScene,  SIGNAL(endAddItem(QString,bool)),
+	    itemPalette, SLOT(endAddItem(QString,bool)));
+    connect(worldScene,  SIGNAL(linkActivated(QUrl)),
+	    infoBrowser, SLOT(openUrl(QUrl)));
+    connect(worldScene,  SIGNAL(endAddItem(QString,bool)),
             this,        SLOT(worldSelectionChanged()));
     
 
@@ -139,7 +140,7 @@ void MainWindow::setupActions()
     KStandardAction::save(this, SLOT(saveFile()), actionCollection());
     KStandardAction::saveAs(this, SLOT(saveFileAs()), actionCollection());
     KStandardAction::quit(this, SLOT(close()), actionCollection());
-    actionRecentFiles = KStandardAction::openRecent(this, SLOT(openFile(const QUrl&)),
+    actionRecentFiles = KStandardAction::openRecent(this, SLOT(openFile(QUrl)),
 						    actionCollection());
 
     KConfig* config = new KConfig("steprc");
@@ -179,10 +180,10 @@ void MainWindow::setupActions()
     connect(worldModel->undoStack(), SIGNAL(canRedoChanged(bool)), actionRedo, SLOT(setEnabled(bool)));
     connect(worldModel->undoStack(), SIGNAL(canUndoChanged(bool)), actionUndo, SLOT(setEnabled(bool)));
     connect(worldModel->undoStack(), SIGNAL(cleanChanged(bool)), this, SLOT(updateCaption()));
-    connect(worldModel->undoStack(), SIGNAL(undoTextChanged(const QString&)),
-                                 this, SLOT(undoTextChanged(const QString&)));
-    connect(worldModel->undoStack(), SIGNAL(redoTextChanged(const QString&)),
-                                 this, SLOT(redoTextChanged(const QString&)));
+    connect(worldModel->undoStack(), SIGNAL(undoTextChanged(QString)),
+                                 this, SLOT(undoTextChanged(QString)));
+    connect(worldModel->undoStack(), SIGNAL(redoTextChanged(QString)),
+                                 this, SLOT(redoTextChanged(QString)));
     
     actionCut = KStandardAction::cut(worldModel, SLOT(cutSelectedItems()),
                                      actionCollection());
@@ -314,35 +315,29 @@ bool MainWindow::openFile(const QUrl& url, const QUrl& startUrl)
 
     QUrl fileUrl = url;
     if(fileUrl.isEmpty()) {
-        fileUrl = KFileDialog::getOpenUrl(startUrl, i18n("*.step|Step files (*.step)"), this); //is this i18n legal?
+        fileUrl = QFileDialog::getOpenFileUrl(this, i18n("Open Step File"), startUrl, i18n("Step files (*.step)"));
         if(fileUrl.isEmpty()) return false;
     }
 
     worldModel->clearWorld();
     newFile();
 
-    QString tmpFileName;
-    if(! KIO::NetAccess::download(fileUrl, tmpFileName, this) ) {
-        KMessageBox::error(this, KIO::NetAccess::lastErrorString());
-        return false;
-    }
-
-    QFile file(tmpFileName);
-    if(!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-        KMessageBox::sorry(this, i18n("Cannot open file '%1'", tmpFileName));
-        KIO::NetAccess::removeTempFile(tmpFileName);
+    QTemporaryFile tempFile;
+    tempFile.open();
+    KIO::FileCopyJob *job = KIO::file_copy(url, QUrl::fromLocalFile(tempFile.fileName()), -1, KIO::Overwrite);
+    KJobWidgets::setWindow(job, this);
+    job->exec();
+    if (job->error()) {
+        KMessageBox::error(this, job->errorString());
         return false;
     }
     
-    if(!worldModel->loadXml(&file)) {
+    if(!worldModel->loadXml(&tempFile)) {
         KMessageBox::sorry(this, i18n("Cannot parse file '%1': %2", fileUrl.url(QUrl::PreferLocalFile),
                                                     worldModel->errorString()));
-        KIO::NetAccess::removeTempFile(tmpFileName);
         return false;
     }
 
-    KIO::NetAccess::removeTempFile(tmpFileName);
-
     worldGraphicsView->fitToPage();
     currentFileUrl = fileUrl;
     updateCaption();
@@ -358,15 +353,18 @@ bool MainWindow::saveFileAs(const QUrl& url, const QUrl& startUrl)
     if(worldModel->isSimulationActive()) simulationStop();
     QUrl fileUrl = url;
     if(fileUrl.isEmpty()) {
-        fileUrl = KFileDialog::getSaveUrl(startUrl.isEmpty() ? currentFileUrl : startUrl,
-                                             i18n("*.step|Step files (*.step)"), this);
+        fileUrl = QFileDialog::getSaveFileUrl(this, i18n("Save Step File"), startUrl.isEmpty() ? currentFileUrl : startUrl, i18n("Step files (*.step)"));
         if(fileUrl.isEmpty()) return false;
-        else if(KIO::NetAccess::exists(fileUrl, KIO::NetAccess::DestinationSide, this)) {
+        else {
+            KIO::StatJob* statJob = KIO::stat(fileUrl, KIO::StatJob::DestinationSide, 0);
+            KJobWidgets::setWindow(statJob, this);
+            if (statJob->exec()) {
             int ret = KMessageBox::warningContinueCancel(this,
                         i18n("The file \"%1\" already exists. Do you wish to overwrite it?",
 			     fileUrl.url(QUrl::PreferLocalFile)),
                         i18n("Warning - Step"), KStandardGuiItem::overwrite());
             if(ret != KMessageBox::Continue) return false;
+            }
         }
     }
 
@@ -396,8 +394,11 @@ bool MainWindow::saveFileAs(const QUrl& url, const QUrl& startUrl)
     }
 
     if(!local) {
-        if(!KIO::NetAccess::upload(file->fileName(), fileUrl, this)) {
-            KMessageBox::error(this, KIO::NetAccess::lastErrorString());
+        KIO::FileCopyJob *job = KIO::file_copy(QUrl::fromLocalFile(file->fileName()), fileUrl, -1, KIO::Overwrite);
+        KJobWidgets::setWindow(job, this);
+        job->exec();
+        if (job->error()) {
+            KMessageBox::error(this, job->errorString());
             delete file;
             return false;
         }
@@ -464,7 +465,7 @@ void MainWindow::openLocalExample()
     // XXX: need to be redone
     QString dir = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + "/examples";
     if(dir.isEmpty()) return;
-    KStandardDirs::makeDir(dir);
+    QDir::root().mkpath(dir);
     openFile(QUrl(), QUrl::fromLocalFile(dir));
 }
 
@@ -602,9 +603,9 @@ void MainWindow::configureStep()
     generalUi.setupUi(generalWidget);
     dialog->addPage(generalWidget, i18n("General"), "step"); //shows the "step" icon, the "general" icon doesn't exist
 
-    connect(dialog, SIGNAL(settingsChanged(const QString&)),
+    connect(dialog, SIGNAL(settingsChanged(QString)),
                 worldGraphicsView, SLOT(settingsChanged())); 
-    connect(dialog, SIGNAL(settingsChanged(const QString&)),
+    connect(dialog, SIGNAL(settingsChanged(QString)),
                 propertiesBrowser, SLOT(settingsChanged())); 
 
     dialog->show();
